Documentation
¶
Overview ¶
package data implements the SRS data client.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DataClient ¶
type DataClient interface {
// Info returns the client information.
Info() types.ClientInfo
// Run starts the SRS data client. It should be called exactly once. The given channel will be closed when the client is ready.
Run(context.Context, *sync.WaitGroup, chan<- any) error
// Send sends a message to the SRS server.
Send(types.Message) error
// IsOnFrequency checks if the named unit is on the client's frequency.
IsOnFrequency(string) bool
// ClientsOnFrequency returns the number of peers on this client's frequency.
ClientsOnFrequency() int
}
DataClient is a client for the SRS data protocol.
func NewClient ¶
func NewClient(guid types.GUID, config types.ClientConfiguration) (DataClient, error)
Click to show internal directories.
Click to hide internal directories.